<?php

if (!defined('ABSPATH')) exit;

class gdpos_admin_data_options {
    private $settings;

    function __construct() {
        $this->init();
    }

    public function get($panel, $group = '') {
        if ($group == '') {
            return $this->settings[$panel];
        } else {
            return $this->settings[$panel][$group];
        }
    }

    public function settings($panel) {
        $list = array();

        foreach ($this->settings[$panel] as $obj) {
            foreach ($obj['settings'] as $o) {
                $list[] = $o;
            }
        }

        return $list;
    }

    private function init() {
        $this->settings = apply_filters('gdpos_admin_internal_settings', array(
            'cache' => array(
                'cache_control' => array('name' => __("Cache Control", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('settings', 'cache_active', __("Active", "gd-power-search-for-bbpress"), __("It is highly recommended to enable use of cache to speed up operations dealing with users or forums.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('cache_active', 'settings')),
                    new d4pSettingElement('settings', 'cache_period', __("Expiration", "gd-power-search-for-bbpress"), __("Expiration is in seconds.", "gd-power-search-for-bbpress"), d4pSettingType::ABSINT, gdpos_settings()->get('cache_period', 'settings'))
                ))
            ),
            'advanced' => array(
                'advanced_form' => array('name' => __("Basic search form", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('settings', 'replace_basic_form', __("Replace the form", "gd-power-search-for-bbpress"), __("Simple search form, default to bbPress is used in various places. With this option you can replace it with that same form with added link to the Power Search page and form.", "gd-power-search-for-bbpress").' '.__("But, if your theme is replacing default bbPress form already, this option will stop that and might cause problems with the search form layout. Check out the Knowledge Base for information how to add link to the Power Search powered form page.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('replace_basic_form', 'settings'))
                ))
            ),
            'control' => array(
                'control_args' => array('name' => __("URL Query", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('settings', 'power_search_query_arg', __("Power Search argument", "gd-power-search-for-bbpress"), __("When this option is enabled, plugin will load Power Search form on the bbPress search page, when the '?power-search' is added to the search URL.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('power_search_query_arg', 'settings'))
                )),
                'control_form' => array('name' => __("Search and Search results Pages", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('settings', 'replace_default_form', __("Replace default form", "gd-power-search-for-bbpress"), __("Plugin will always replace default search form on the bbPress search page.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('replace_default_form', 'settings')),
                    new d4pSettingElement('settings', 'results_collapsed_form', __("Collapsed on the results page", "gd-power-search-for-bbpress"), __("Power search form will be displayed on the top of the search results page, but in the collapsed state.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('results_collapsed_form', 'settings'))
                ))
            ),
            'filters' => array(
                'filters_types' => array('name' => __("Content Types", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'types', __("Show 'Types' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Types' field to select which forum post types to search through (topics and/or replies).", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('types', 'form')),
                    new d4pSettingElement('form', 'types_default', __("Default value", "gd-power-search-for-bbpress"), "", d4pSettingType::SELECT, gdpos_settings()->get('types_default', 'form'), 'array', gdpos()->form()->data_types()),
                    new d4pSettingElement('form', 'types_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('types_visitors', 'form')),
                    new d4pSettingElement('form', 'types_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('types_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                )),
                'filters_status' => array('name' => __("Topic Status", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'status', __("Show 'status' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Topic Status' field to search topics based on the status.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('status', 'form')),
                    new d4pSettingElement('form', 'status_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('status_visitors', 'form')),
                    new d4pSettingElement('form', 'status_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('status_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                )),
                'filters_forums' => array('name' => __("Forums", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'forums', __("Show 'Forums' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Forums' field to select which forums to search.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('forums', 'form')),
                    new d4pSettingElement('form', 'forums_subforums', __("Show 'Subforums' field", "gd-power-search-for-bbpress"), __("When user selects forums to search, with this option will also search all subforums to selected forums.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('forums_subforums', 'form')),
                    new d4pSettingElement('form', 'forums_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('forums_visitors', 'form')),
                    new d4pSettingElement('form', 'forums_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('forums_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                )),
                'filters_users' => array('name' => __("Users", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'users', __("Show 'Users' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Users' field to select which forum users to include in the search.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('users', 'form')),
                    new d4pSettingElement('form', 'users_format', __("Field Format", "gd-power-search-for-bbpress"), __("Field format 'Select' is not recommended for forums with large number of users", "gd-power-search-for-bbpress"), d4pSettingType::SELECT, gdpos_settings()->get('users_format', 'form'), 'array', $this->data_users_formats()),
                    new d4pSettingElement('form', 'users_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('users_visitors', 'form')),
                    new d4pSettingElement('form', 'users_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('users_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                )),
                'filters_tags' => array('name' => __("Topic Tags", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'tags', __("Show 'Topic Tags' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Tags' field to select which Topic Tags to search for.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('tags', 'form')),
                    new d4pSettingElement('form', 'tags_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('tags_visitors', 'form')),
                    new d4pSettingElement('form', 'tags_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('tags_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                )),
                'filters_period' => array('name' => __("Date Period", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'period', __("Show 'Date Period' field", "gd-power-search-for-bbpress"), __("Plugin will load 'Date Period' field to select which published period to search through.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('period', 'form')),
                    new d4pSettingElement('form', 'period_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('period_visitors', 'form')),
                    new d4pSettingElement('form', 'period_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('period_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                ))
            ),
            'results' => array(
                'results_order' => array('name' => __("Results Order", "gd-power-search-for-bbpress"), 'settings' => array(
                    new d4pSettingElement('form', 'order', __("Show 'Order' fields", "gd-power-search-for-bbpress"), __("Plugin will load 'Order' and 'Order by' fields to control search results sorting.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('order', 'form')),
                    new d4pSettingElement('form', 'order_visitors', __("Available to visitors", "gd-power-search-for-bbpress"), __("If enabled, this field will be available to website anonymous visitors.", "gd-power-search-for-bbpress"), d4pSettingType::BOOLEAN, gdpos_settings()->get('order_visitors', 'form')),
                    new d4pSettingElement('form', 'order_roles', __("Available to user roles", "gd-power-search-for-bbpress"), __("User with selected roles will be able to use this field.", "gd-power-search-for-bbpress"), d4pSettingType::CHECKBOXES, gdpos_settings()->get('order_roles', 'form'), 'array', gdpos_get_user_roles(), array('class' => 'gdpos-roles'))
                ))
            )
        ));
    }

    public function data_users_formats() {
        return array(
            'input' => __("Input: enter full or partial user name", "gd-power-search-for-bbpress"),
            'select' => __("Select: select a single user from the list", "gd-power-search-for-bbpress")
        );
    }
}
