<?php

if (!defined('ABSPATH')) exit;

class gdpos_admin_postback {
    public $id = 0;
    public $name = '';
    public $object = null;

    public function __construct() {
        $page = isset($_POST['option_page']) ? sanitize_text_field($_POST['option_page']) : false;

        if ($page !== false) {
            if ($page == 'gd-power-search-for-bbpress-tools') {
                $this->tools();
            }

            if ($page == 'gd-power-search-for-bbpress-settings') {
                $this->settings();
            }

            do_action('gdpos_admin_postback_handler', $page);
        }
    }

    public function tools() {
        check_admin_referer('gd-power-search-for-bbpress-tools-options');

        if (gdpos_admin()->task == 'remove') {
            $this->remove();
        } else if (gdpos_admin()->task == 'cache') {
            $this->cache();
        } else if (gdpos_admin()->task == 'import') {
            $this->import();
        }
    }

    private function remove() {
        $valid_keys = array('settings', 'disable');

        $remove = isset($_POST['gdpostools']['remove']) ? (array)$_POST['gdpostools']['remove'] : array();
        $remove = $this->sanitize_post_input($remove, $valid_keys);

        if (empty($remove)) {
            $message = '&message=nothing';
        } else {
            if (isset($remove['settings']) && $remove['settings'] == 'on') {
                gdpos_settings()->remove_plugin_settings_by_group('info');
                gdpos_settings()->remove_plugin_settings_by_group('core');
                gdpos_settings()->remove_plugin_settings_by_group('form');
                gdpos_settings()->remove_plugin_settings_by_group('settings');

                $message = '&message=settings-removed';
            }

            if (isset($remove['disable']) && $remove['disable'] == 'on') {
                deactivate_plugins('gd-power-search-for-bbpress/gd-power-search-for-bbpress.php', false, false);

                wp_redirect(admin_url('plugins.php'));
                exit;
            }
        }

        wp_redirect(gdpos_admin()->current_url().$message);
        exit;
    }

    private function cache() {
        $valid_keys = array('transient');

        $remove = isset($_POST['gdpostools']['cache']) ? (array)$_POST['gdpostools']['cache'] : array();
        $remove = $this->sanitize_post_input($remove, $valid_keys);

        if (empty($remove)) {
            $message = '&message=nothing';
        } else {
            if (isset($remove['transient']) && $remove['transient'] == 'on') {
                gdpos()->cache()->clear();

                $message = '&message=cache-removed';
            }
        }

        wp_redirect(gdpos_admin()->current_url().$message);
        exit;
    }

    private function import() {
        $message = '&message=import-failed';

        if (is_uploaded_file($_FILES['import_file']['tmp_name'])) {
            $raw = file_get_contents($_FILES['import_file']['tmp_name']);
            $data = maybe_unserialize($raw);

            if (is_object($data)) {
                gdpos_settings()->import_from_object($data);

                $message = '&message=imported';
            }
        }

        wp_redirect(gdpos_admin()->current_url(false, false).$message);
        exit;
    }

    private function settings() {
        check_admin_referer('gd-power-search-for-bbpress-settings-options');

        $this->save_settings(gdpos_admin()->task);

        wp_redirect(gdpos_admin()->current_url().'&message=saved');
        exit;
    }

    private function save_settings($panel) {
        require_once(GDPOS_D4PLIB.'admin/d4p.functions.php');
        require_once(GDPOS_D4PLIB.'admin/d4p.settings.php');

        require_once(GDPOS_PATH.'core/admin/options.php');

        $options = new gdpos_admin_data_options();
        $settings = $options->settings($panel);

        $processor = new d4pSettingsProcess($settings);
        $processor->base = 'gdposvalue';

        $data = $processor->process();

        foreach ($data as $group => $values) {
            if (!empty($group)) {
                foreach ($values as $name => $value) {
                    $value = apply_filters('gdposb_settings_save_settings_value', $value, $name, $group);

                    gdpos_settings()->set($name, $value, $group);
                }

                gdpos_settings()->save($group);
            }
        }
    }

    private function sanitize_post_input($input, $keys) {
        $valid = array();

        foreach ($input as $key => $value) {
            if (in_array($key, $keys)) {
                $valid[$key] = sanitize_text_field($value);
            }
        }

        return $valid;
    }
}
