<?php

if (!defined('ABSPATH')) exit;

function gdpos_has_bbpress() {
    if (function_exists('bbp_get_version')) {
        $version = bbp_get_version();
        $version = intval(substr(str_replace('.', '', $version), 0, 2));

        return $version > 24;
    } else {
        return false;
    }
}

function gdpos_get_search_results_url() {
    $search_terms = bbp_get_search_terms();

    if (empty($search_terms)) {
        $search_terms = '-';
    }

    if (bbp_use_pretty_urls()) {
        $url = bbp_get_root_url().bbp_get_search_slug();

        $url = trailingslashit($url).urlencode($search_terms);

        $url = user_trailingslashit($url);
        $url = home_url($url);
    } else {
        $url = add_query_arg( array(
            bbp_get_search_rewrite_id() => urlencode($search_terms)
        ), home_url('/'));
    }

    return apply_filters( 'gdpos_get_search_results_url', $url );
}

function gdpos_form_select_attributes($args = array(), $attr = array()) {
    $defaults = array('name' => '', 'id' => '', 'class' => '', 'style' => '', 'multi' => false, 'readonly' => false);
    $args = wp_parse_args($args, $defaults);

    extract($args);

    $name = $multi ? $name.'[]' : $name;

    $attributes = array(
        'id="'.esc_attr($id).'"',
        'name="'.esc_attr($name).'"'
    );

    if ($class != '') {
        $attributes[] = 'class="'.esc_attr($class).'"';
    }

    if ($style != '') {
        $attributes[] = 'style="'.esc_attr($style).'"';
    }

    if ($multi) {
        $attributes[] = 'multiple';
    }

    if ($readonly) {
        $attributes[] = 'readonly';
    }

    foreach ($attr as $key => $value) {
        $attributes[] = $key.'="'.esc_attr($value).'"';
    }

    return $attributes;
}

function gdpos_form_select($values, $s, $args = array(), $attr = array(), $echo = true) {
    $attributes = gdpos_form_select_attributes($args, $attr);
    $selected = is_null($s) ? array_keys($values) : (array)$s;

    $render = '<select '.join(' ', $attributes).'>';

    foreach ($values as $value => $display) {
        $sel = in_array($value, $selected) ? ' selected="selected"' : '';
        $render.= '<option value="'.esc_attr($value).'"'.$sel.'>'.$display.'</option>';
    }

    $render.= '</select>';

    if ($echo) {
        echo $render;
    } else {
        return $render;
    }
}

function gdpos_form_select_forums($s, $args = array(), $attr = array(), $echo = true) {
    $attributes = gdpos_form_select_attributes($args, $attr);

    $r = gdpos()->form()->args_forums_list();
    $r['selected'] = (array)$s;

    $render = '<select '.join(' ', $attributes).'>';

    $posts = get_posts($r);
    $render.= walk_page_dropdown_tree($posts, 0, $r);

    $render.= '</select>';

    if ($echo) {
        echo $render;
    } else {
        return $render;
    }
}

function gdpos_get_user_roles() {
    $roles = array();

    $dynamic_roles = bbp_get_dynamic_roles();

    foreach ($dynamic_roles as $role => $obj) {
        $roles[$role] = $obj['name'];
    }

    return $roles;
}

function gdpos_power_search_url() {
    echo esc_url(gdpos_get_power_search_url());
}

function gdpos_get_power_search_url() {
    $url = bbp_get_search_url();

    if (!gdpos_settings()->get('replace_default_form')) {
        $url = add_query_arg('power-search', '', $url);
    }

    return $url;
}
