<?php

if (!defined('ABSPATH')) exit;

class gdpos_core_bbpress {
    public $search_loaded = false;

    public function __construct() {
        add_action('gdpos_plugin_init', array($this, 'init'));
    }

    public function init() {
        add_filter('bbp_get_template_stack', array($this, 'template_stack'));

        add_action('bbp_get_request', array($this, 'search_request'), 9);
        add_filter('bbp_get_search_results_url', array($this, 'search_results_url'));
        add_filter('bbp_after_has_search_results_parse_args', array($this, 'has_search_results'));

        if ((gdpos_settings()->get('power_search_query_arg') && gdpos()->search()->is_power()) || gdpos_settings()->get('replace_default_form')) {
            add_action('bbp_template_before_search', array($this, 'search_to_power_search'), 40);
        }

        if (gdpos_settings()->get('replace_basic_form')) {
            add_action('bbp_get_template_part', array($this, 'replace_basic_search_form'), 66, 3);
        }

        add_action('bbp_template_before_search', array($this, 'search_request'), 20);

        add_action('bbp_template_before_search', array($this, 'search_force_form'), 30);

        add_filter('bbp_template_before_pagination_loop', array($this, 'fix_pagination'));
    }

    public function replace_basic_search_form($templates, $slug, $name) {
        if ($slug == 'form' && $name == 'search') {
            $templates = array('form-search-basic.php');
        }

        return $templates;
    }

    public function template_stack($stack) {
        $stack[] = GDPOS_PATH.'templates/default/bbpress';

        return $stack;
    }

    public function search_request() {
        if (isset($_GET['gdpos']) && $_GET['gdpos'] == 'power-search-request') {
            do_action('gdpos_parse_query_string');
        }
    }

    public function search_force_form() {
        if (!$this->search_loaded) {
            if (bbp_is_search_results() && gdpos_settings()->get('results_collapsed_form')) {
                add_action('bbp_enqueue_scripts', array($this, 'enqueue_files'));

                bbp_get_template_part('content', 'search-wrapper');

                $this->search_loaded = true;
            } else if (!bbp_is_search_results() && gdpos_settings()->get('replace_default_form')) {
                add_action('bbp_enqueue_scripts', array($this, 'enqueue_files'));

                bbp_get_template_part('form', 'search-power');

                $this->search_loaded = true;
            }
        }

        if ($this->search_loaded) {
            if (!bbp_has_search_results() && !bbp_get_search_terms()) {
                add_action('bbp_get_template_part', array($this, 'remove_search_form'), 88, 3);
            }
        }
    }

    public function fix_pagination() {
        $links = bbpress()->search_query->pagination_links;

        $output = array();
        preg_match_all("/'((http.+?)(\?gdpos=power-search.+?)\/(.+?))'/", $links, $output);

        $count = isset($output[0]) ? count($output[0]) : 0;

        if ($count > 0) {
            for ($i = 0; $i < $count; $i++) {
                $find = $output[1][$i];
                $replace = $output[2][$i].$output[4][$i].$output[3][$i];

                $links = str_replace($find, $replace, $links);
            }

            bbpress()->search_query->pagination_links = $links;
        }
    }

    public function search_results_url($url) {
        if (gdpos()->search()->is_power()) {
            $url = gdpos_get_search_results_url();
            $url = add_query_arg('gdpos', 'power-search-request', $url);

            foreach (gdpos()->search()->get_query() as $key => $value) {
                $do = is_array($value) ? $value : urlencode($value);
                $url = add_query_arg('gdpos_search_'.$key, $do, $url);
            }
        }

        return $url;
    }

    public function has_search_results($args) {
        if (gdpos()->search()->is_power()) {
            $args = gdpos()->search()->search_query_args($args);
        }

        return $args;
    }

    public function search_to_power_search() {
        if (!$this->search_loaded) {
            add_action('bbp_enqueue_scripts', array($this, 'enqueue_files'));
            add_action('bbp_get_template_part', array($this, 'replace_search_form'), 77, 3);
        }
    }

    public function replace_search_form($templates, $slug, $name) {
        if ($slug == 'form' && $name == 'search') { d4p_print_r('xxxYxxx');
            remove_action('bbp_get_template_part', array($this, 'replace_search_form'), 77);

            $templates = array('form-search-power.php');
        }

        return $templates;
    }

    public function file($type, $name, $path) {
        $get = GDPOS_URL.'templates/default/'.$path.'/'.$name;

        if (!gdpos()->is_debug) {
            $get.= '.min';
        }

        $get.= '.'.$type;

        return $get;
    }

    public function allowed_forums_ids() {
        return apply_filters('gdpos_allowed_forums_ids_list', array());
    }

    public function disallowed_forums_ids() {
        return apply_filters('gdpos_disallowed_forums_ids_list', array());
    }

    public function enqueue_files() {
        $depend = array(
            'css' => array(),
            'js' => array('jquery')
        );

        wp_enqueue_style('gdpos-search', $this->file('css', 'search', 'css'), $depend['css'], gdpos_settings()->file_version());
        wp_enqueue_script('gdpos-search', $this->file('js', 'search', 'js'), $depend['js'], gdpos_settings()->file_version(), true);
    }

    private function _keywords() {
        $exclusion_prefix = apply_filters('wp_query_search_exclusion_prefix', '-');

        $input = bbp_get_search_terms();
        $input = explode(' ', $input);

        $keywords = array();

        foreach ($input as $term) {
            $exclude = $exclusion_prefix && ($exclusion_prefix === substr($term, 0, 1));

            if (!$exclude) {
                $keywords[] = $term;
            }
        }

        return $keywords;
    }
}
