<?php

if (!defined('ABSPATH')) exit;

class gdpos_core_cache {
    public $cache = true;
    public $cache_key = 'gdpos-';
    public $cache_ttl = 86400;

    public function __construct() {}

    public function forum_authors() {
        $data = $this->_get('forum-authors');

        if ($data === false) {
            $data = $this->_forum_authors();

            $this->_set('forum-authors', $data);
        }

        return $data;
    }

    public function public_forums() {
        $data = $this->_get('public-forums');

        if ($data === false) {
            $data = $this->_public_forums();

            $this->_set('public-forums', $data);
        }

        return $data;
    }

    public function forums_with_subforums($ids) {
        $list = $ids;

        foreach ($ids as $id) {
            $subforums = $this->_get('forum-subforums-'.$id);

            if ($subforums === false) {
                $subforums = $this->_forum_subforums($id);

                $this->_set('forum-subforums-'.$id, $subforums);
            }

            if (!empty($subforums)) {
                $list = array_merge($list, $subforums);
            }
        }

        $list = array_unique($list);
        $list = array_filter($list);

        return $list;
    }

    private function _get($key) {
        if ($this->cache) {
            return get_transient($this->cache_key.$key);
        }

        return false;
    }

    private function _set($key, $data, $ttl = null) {
        if ($this->cache) {
            $ttl = is_null($ttl) ? $this->cache_ttl : $ttl;
            set_transient($this->cache_key.$key, $data, $ttl);
        }
    }

    private function _forum_authors() {
        return gdpos_db()->get_forum_authors();
    }

    private function _public_forums() {
        return gdpos_db()->get_private_forums();
    }

    private function _forum_subforums($id) {
        $children = get_posts(array('fields' => 'ids', 'numberposts' => -1, 'post_status' => 'publish', 'post_type' => bbp_get_forum_post_type(), 'post_parent' => $id, 'suppress_filters' => true));

        foreach ($children as $sub_id) {
            $sub_children = $this->_forum_subforums($sub_id);

            if (!empty($sub_children)) {
                $children = array_merge($children, $sub_children);
            }
        }

        return $children;
    }

    public function clear() {
        $key_base = 'gdpos%';

        $sql = sprintf("DELETE FROM %s WHERE option_name LIKE '_transient_%s' OR option_name LIKE '_transient_timeout_%s'", gdpos_db()->wpdb()->options, $key_base, $key_base);

        gdpos_db()->query($sql);
    }
}
