<?php

if (!defined('ABSPATH')) exit;

class gdpos_core_form {
    public function __construct() { }

    public function show($name) {
        $show = gdpos_settings()->get($name, 'form');

        if ($show) {
            if (!is_user_logged_in()) {
                $show = gdpos_settings()->get($name.'_visitors', 'form');
            } else {
                $roles = gdpos_settings()->get($name.'_roles', 'form');

                if (is_array($roles)) {
                    if (empty($roles)) {
                        $show = false;
                    } else {
                        global $current_user;

                        if (is_array($current_user->roles)) {
                            $matched = array_intersect($current_user->roles, $roles);
                            $show = !empty($matched);
                        }
                    }
                }
            }
        }

        return apply_filters('gdpos_form_show_'.$name, $show);
    }

    public function get($name) {
        $show = gdpos_settings()->get($name, 'form');

        return apply_filters('gdpos_form_get_'.$name, $show);
    }

    public function data_forums() {
        $list = array(
            'all' => __("All available Forums", "gd-power-search-for-bbpress"),
            'public' => __("Only public Forums", "gd-power-search-for-bbpress"),
            'subscribed' => __("Only Subscribed Forums", "gd-power-search-for-bbpress"),
            'forums' => __("Selected Forums", "gd-power-search-for-bbpress")
        );

        if (!is_user_logged_in()) {
            unset($list['subscribed']);
        }

        return $list;
    }

    public function data_select_authors() {
        return array(
            '' => __("Select author", "gd-power-search-for-bbpress")
        ) + gdpos()->cache()->forum_authors();
    }

    public function data_yes_no() {
        return array(
            'yes' => __("Yes", "gd-power-search-for-bbpress"),
            'no' => __("No", "gd-power-search-for-bbpress")
        );
    }

    public function data_status() {
        return array(
            'all' => __("All Topics", "gd-power-search-for-bbpress"),
            bbp_get_public_status_id() => __("Published Topics", "gd-power-search-for-bbpress"),
            bbp_get_closed_status_id() => __("Closed Topics", "gd-power-search-for-bbpress")
        );
    }

    public function data_orderby() {
        return array(
            'ID' => __("ID", "gd-power-search-for-bbpress"),
            'date' => __("Date", "gd-power-search-for-bbpress"),
            'title' => __("Title", "gd-power-search-for-bbpress"),
            'author' => __("Author", "gd-power-search-for-bbpress")
        );
    }

    public function data_order() {
        return array(
            'ASC' => __("Ascending", "gd-power-search-for-bbpress"),
            'DESC' => __("Descending", "gd-power-search-for-bbpress")
        );
    }

    public function data_types() {
        return array(
            'posts' => __("Topics and Replies", "gd-power-search-for-bbpress"),
            'topic' => __("Topics Only", "gd-power-search-for-bbpress"),
            'reply' => __("Replies Only", "gd-power-search-for-bbpress")
        );
    }

    public function data_period() {
        $list = array(
            'any' => __("Any day", "gd-power-search-for-bbpress"),
            'day' => __("Last 24 hours", "gd-power-search-for-bbpress"),
            'week' => __("Last 7 days", "gd-power-search-for-bbpress"),
            'month' => __("Last 30 days", "gd-power-search-for-bbpress"),
            'half' => __("Last 6 months", "gd-power-search-for-bbpress"),
            'year' => __("Last 12 months", "gd-power-search-for-bbpress")
        );

        return $list;
    }

    public function args_forums_list() {
        $args = array(
            'post_type' => bbp_get_forum_post_type(),
            'post_parent' => null,
            'post_status' => null,
            'numberposts' => -1,
            'orderby'=> 'menu_order title',
            'disable_categories' => false,
            'order' => 'ASC',
            'walker' => new gdpos_walker_forums_dropdown()
        );

        $_include = gdpos()->bbpress()->allowed_forums_ids();

        if (!empty($_include)) {
            $args['include'] = $_include;
        } else {
            $_exclude = gdpos()->bbpress()->disallowed_forums_ids();

            if (!empty($_exclude)) {
                $args['exclude'] = $_exclude;
            }
        }

        return $args;
    }

    public function show_block_filters() {
        return $this->show('types') ||
               $this->show('status') ||
               $this->show('forums') ||
               $this->show('users') ||
               $this->show('tags') ||
               $this->show('period');
    }

    public function show_block_results() {
        return $this->show('order');
    }
}
