<?php

if (!defined('ABSPATH')) exit;

class gdpos_core_plugin extends d4p_plugin_core {
    public $plugin = 'gd-power-search-for-bbpress';

    private $_bbpress;
    private $_search;
    private $_form;
    private $_cache;

    public function __construct() {
        parent::__construct();

        $this->_bbpress = new gdpos_core_bbpress();
        $this->_search = new gdpos_core_search();
        $this->_form = new gdpos_core_form();
        $this->_cache = new gdpos_core_cache();

        $this->url = GDPOS_URL;
    }

    /** @return gdpos_core_bbpress */
    public function bbpress() {
        return $this->_bbpress;
    }

    /** @return gdpos_core_search */
    public function search() {
        return $this->_search;
    }

    /** @return gdpos_core_form */
    public function form() {
        return $this->_form;
    }

    /** @return gdpos_core_cache */
    public function cache() {
        return $this->_cache;
    }

    public function plugins_loaded() {
        parent::plugins_loaded();

        define('GDPOS_WPV', intval($this->wp_version));
        define('GDPOS_WPV_MAJOR', substr($this->wp_version, 0, 3));

        if (GDPOS_WPV < 45) {
            add_action('admin_notices', array($this, 'system_requirements_problem'));
        }

        if (!gdpos_has_bbpress()) {
            add_action('admin_notices', array($this, 'bbpress_requirements_problem'));
        }

        do_action('gdpos_load_settings');

        $this->cache()->cache = gdpos_settings()->get('cache_active');
        $this->cache()->cache_ttl = gdpos_settings()->get('cache_period');

        do_action('gdpos_plugin_init');
    }

    public function system_requirements_problem() {
        ?>

<div class="notice notice-error">
    <p><?php echo sprintf(__("GD Power Search Pro for bbPress requires WordPress %s or newer. Plugin will now be disabled. To use this plugin, upgrade WordPress to %s or newer version.", "gd-power-search-for-bbpress"), '4.5', '4.5'); ?></p>
</div>

        <?php

        $this->deactivate();
    }

    public function bbpress_requirements_problem() {
        ?>

<div class="notice notice-error">
    <p><?php echo sprintf(__("GD Power Search Pro requires bbPress plugin version %s or newer. Plugin will now be disabled. To use this plugin, make sure you are using bbPress %s or newer version.", "gd-power-search-for-bbpress"), '2.5', '2.5'); ?></p>
</div>

        <?php

        $this->deactivate();
    }

    public function deactivate() {
        deactivate_plugins('gd-power-search-for-bbpress/gd-power-search-for-bbpress.php', false);
    }

    public function load_textdomain() {
        load_plugin_textdomain($this->plugin, false, $this->plugin.'/languages');
        load_plugin_textdomain('d4plib', false, $this->plugin.'/d4plib/languages');
    }

    public function locale() {
        return apply_filters('plugin_locale', get_user_locale(), $this->plugin);
    }
}
